@@ -4,9 +4,8 @@
 
 library test.edit.all;
 
-import 'package:unittest/unittest.dart';
+import 'package:test_reflective_loader/test_reflective_loader.dart';
 
-import '../utils.dart';
 import 'assists_test.dart' as assists_test;
 import 'fixes_test.dart' as fixes_test;
 import 'format_test.dart' as format_test;
@@ -18,13 +17,12 @@ import 'sort_members_test.dart' as sort_members_test;
  * Utility for manually running all tests.
  */
 main() {
-  initializeTestEnvironment();
-  group('edit', () {
+  defineReflectiveSuite(() {
     assists_test.main();
     fixes_test.main();
     format_test.main();
     organize_directives_test.main();
     refactoring_test.main();
     sort_members_test.main();
-  });
+  }, name: 'edit');
 }
