@@ -4,9 +4,8 @@
 
 library test.integration.analysis.all;
 
-import 'package:unittest/unittest.dart';
+import 'package:test_reflective_loader/test_reflective_loader.dart';
 
-import '../../utils.dart';
 import 'analysis_options_test.dart' as analysis_options_test;
 import 'error_test.dart' as error_test;
 import 'get_errors_after_analysis_test.dart' as get_errors_after_analysis_test;
@@ -31,8 +30,7 @@ import 'update_content_test.dart' as update_content_test;
  * Utility for manually running all integration tests.
  */
 main() {
-  initializeTestEnvironment();
-  group('analysis', () {
+  defineReflectiveSuite(() {
     analysis_options_test.main();
     error_test.main();
     get_errors_after_analysis_test.main();
@@ -51,5 +49,5 @@ main() {
     reanalyze_test.main();
     update_content_test.main();
     update_content_list_test.main();
-  });
+  }, name: 'analysis');
 }
