@@ -15,16 +15,16 @@ import 'package:analyzer/src/dart/ast/utilities.dart' as engine;
 import 'package:analyzer/src/dart/element/element.dart' as engine;
 import 'package:analyzer/src/error/codes.dart' as engine;
 import 'package:analyzer/src/generated/source.dart' as engine;
+import 'package:test/test.dart';
 import 'package:test_reflective_loader/test_reflective_loader.dart';
-import 'package:unittest/unittest.dart';
 
 import '../abstract_context.dart';
-import '../utils.dart';
 
 main() {
-  initializeTestEnvironment();
-  defineReflectiveTests(ElementTest);
-  defineReflectiveTests(ElementKindTest);
+  defineReflectiveSuite(() {
+    defineReflectiveTests(ElementTest);
+    defineReflectiveTests(ElementKindTest);
+  });
 }
 
 @reflectiveTest
