@@ -7,15 +7,15 @@ library test.services.completion.target;
 import 'package:analysis_server/src/provisional/completion/dart/completion_target.dart';
 import 'package:analyzer/dart/ast/ast.dart';
 import 'package:analyzer/src/generated/source.dart';
+import 'package:test/test.dart';
 import 'package:test_reflective_loader/test_reflective_loader.dart';
-import 'package:unittest/unittest.dart';
 
 import '../../abstract_context.dart';
-import '../../utils.dart';
 
 main() {
-  initializeTestEnvironment();
-  defineReflectiveTests(CompletionTargetTest);
+  defineReflectiveSuite(() {
+    defineReflectiveTests(CompletionTargetTest);
+  });
 }
 
 @reflectiveTest
@@ -45,6 +45,7 @@ class CompletionTargetTest extends AbstractContextTest {
           reason: 'containingNode');
       expect(target.argIndex, argIndex, reason: 'argIndex');
     }
+
     // Assert with parsed unit
     assertCommon();
     CompilationUnit unit =
