@@ -7,15 +7,15 @@ library test.services.completion.dart.arglist;
 import 'package:analysis_server/plugin/protocol/protocol.dart';
 import 'package:analysis_server/src/provisional/completion/dart/completion_dart.dart';
 import 'package:analysis_server/src/services/completion/dart/arglist_contributor.dart';
+import 'package:test/test.dart';
 import 'package:test_reflective_loader/test_reflective_loader.dart';
-import 'package:unittest/unittest.dart';
 
-import '../../../utils.dart';
 import 'completion_contributor_util.dart';
 
 main() {
-  initializeTestEnvironment();
-  defineReflectiveTests(ArgListContributorTest);
+  defineReflectiveSuite(() {
+    defineReflectiveTests(ArgListContributorTest);
+  });
 }
 
 @reflectiveTest
