@@ -20,7 +20,9 @@ const Map<String, LibraryInfo> libraries = const {
   "collection": const LibraryInfo("collection/collection.dart"),
   "convert": const LibraryInfo("convert/convert.dart"),
   "core": const LibraryInfo("core/core.dart"),
-  "html": const LibraryInfo("html/dartium/html_dartium.dart"),
+  "html": const LibraryInfo(
+    "html/dartium/html_dartium.dart",
+    dart2jsPath: "html/dart2js/html_dart2js.dart"),
   "math": const LibraryInfo("math/math.dart"),
   "_foreign_helper": const LibraryInfo("_internal/js_runtime/lib/foreign_helper.dart"),
 };
@@ -265,7 +267,15 @@ JS(String typeDescription, String codeTemplate,
 {}
 ''');
 
-const _MockSdkLibrary _LIB_HTML = const _MockSdkLibrary(
+const _MockSdkLibrary _LIB_HTML_DART2JS = const _MockSdkLibrary(
+    'dart:html',
+    '$sdkRoot/lib/html/dart2js/html_dart2js.dart',
+    '''
+library dart.html;
+class HtmlElement {}
+''');
+
+const _MockSdkLibrary _LIB_HTML_DARTIUM = const _MockSdkLibrary(
     'dart:html',
     '$sdkRoot/lib/html/dartium/html_dartium.dart',
     '''
@@ -303,7 +313,8 @@ const List<SdkLibrary> _LIBRARIES = const [
   _LIB_CONVERT,
   _LIB_FOREIGN_HELPER,
   _LIB_MATH,
-  _LIB_HTML,
+  _LIB_HTML_DART2JS,
+  _LIB_HTML_DARTIUM,
 ];
 
 class MockSdk implements DartSdk {
@@ -339,18 +350,21 @@ class MockSdk implements DartSdk {
    */
   PackageBundle _bundle;
 
-  MockSdk({bool dartAsync: true, resource.ResourceProvider resourceProvider})
+  MockSdk(
+      {bool dartAsync: true, resource.MemoryResourceProvider resourceProvider})
       : provider = resourceProvider ?? new resource.MemoryResourceProvider(),
         sdkLibraries = dartAsync ? _LIBRARIES : [_LIB_CORE],
         uriMap = dartAsync ? FULL_URI_MAP : NO_ASYNC_URI_MAP {
     for (_MockSdkLibrary library in sdkLibraries) {
-      provider.newFile(library.path, library.content);
+      provider.newFile(provider.convertPath(library.path), library.content);
       library.parts.forEach((String path, String content) {
-        provider.newFile(path, content);
+        provider.newFile(provider.convertPath(path), content);
       });
     }
     provider.newFile(
-        '/_internal/sdk_library_metadata/lib/libraries.dart', librariesContent);
+        provider.convertPath(
+            '$sdkRoot/lib/_internal/sdk_library_metadata/lib/libraries.dart'),
+        librariesContent);
   }
 
   @override
@@ -381,7 +395,8 @@ class MockSdk implements DartSdk {
       String libraryPath = library.path;
       if (filePath.replaceAll('\\', '/') == libraryPath) {
         try {
-          resource.File file = provider.getResource(uri.path);
+          resource.File file =
+              provider.getResource(provider.convertPath(filePath));
           Uri dartUri = Uri.parse(library.shortName);
           return file.createSource(dartUri);
         } catch (exception) {
@@ -392,7 +407,8 @@ class MockSdk implements DartSdk {
         String pathInLibrary = filePath.substring(libraryPath.length + 1);
         String path = '${library.shortName}/$pathInLibrary';
         try {
-          resource.File file = provider.getResource(uri.path);
+          resource.File file =
+              provider.getResource(provider.convertPath(filePath));
           Uri dartUri = new Uri(scheme: 'dart', path: path);
           return file.createSource(dartUri);
         } catch (exception) {
@@ -429,11 +445,10 @@ class MockSdk implements DartSdk {
   Source mapDartUri(String dartUri) {
     String path = uriMap[dartUri];
     if (path != null) {
-      resource.File file = provider.getResource(path);
+      resource.File file = provider.getResource(provider.convertPath(path));
       Uri uri = new Uri(scheme: 'dart', path: dartUri.substring(5));
       return file.createSource(uri);
     }
-
     // If we reach here then we tried to use a dartUri that's not in the
     // table above.
     return null;
@@ -447,6 +462,7 @@ class MockSdk implements DartSdk {
     assert(_analysisContext == null);
     String path = FULL_URI_MAP[uri];
     assert(path != null);
+    path = provider.convertPath(path);
     String content = provider.getFile(path).readAsStringSync();
     String newContent = updateContent(content);
     provider.updateFile(path, newContent);
@@ -482,6 +498,9 @@ class _MockSdkLibrary implements SdkLibrary {
 
   @override
   bool get isVmLibrary => throw new UnimplementedError();
+
+  @override
+  List<String> getPatches(int platform) => const <String>[];
 }
 
 /**
