@@ -6,6 +6,7 @@ library analyzer.test.src.summary.resynthesize_ast_test;
 
 import 'package:analyzer/dart/ast/ast.dart';
 import 'package:analyzer/dart/element/element.dart';
+import 'package:analyzer/error/error.dart';
 import 'package:analyzer/src/dart/element/element.dart';
 import 'package:analyzer/src/generated/engine.dart'
     show AnalysisContext, AnalysisOptionsImpl;
@@ -21,8 +22,8 @@ import 'package:analyzer/src/summary/summarize_elements.dart'
     show PackageBundleAssembler;
 import 'package:analyzer/task/dart.dart' show PARSED_UNIT;
 import 'package:analyzer/task/general.dart';
+import 'package:test/test.dart';
 import 'package:test_reflective_loader/test_reflective_loader.dart';
-import 'package:unittest/unittest.dart';
 
 import '../context/abstract_context.dart';
 import '../task/strong/inferred_type_test.dart';
@@ -30,10 +31,11 @@ import 'resynthesize_common.dart';
 import 'summary_common.dart';
 
 main() {
-  groupSep = ' | ';
-  defineReflectiveTests(ResynthesizeAstSpecTest);
-  defineReflectiveTests(ResynthesizeAstStrongTest);
-  defineReflectiveTests(AstInferredTypeTest);
+  defineReflectiveSuite(() {
+    defineReflectiveTests(ResynthesizeAstSpecTest);
+    defineReflectiveTests(ResynthesizeAstStrongTest);
+    defineReflectiveTests(AstInferredTypeTest);
+  });
 }
 
 @reflectiveTest
@@ -70,9 +72,8 @@ class AstInferredTypeTest extends AbstractResynthesizeTest
   DartSdk createDartSdk() => AbstractContextTest.SHARED_STRONG_MOCK_SDK;
 
   @override
-  AnalysisOptionsImpl createOptions() => new AnalysisOptionsImpl()
-    ..enableGenericMethods = true
-    ..strongMode = true;
+  AnalysisOptionsImpl createOptions() =>
+      new AnalysisOptionsImpl()..strongMode = true;
 
   @override
   @failingTest
@@ -615,6 +616,14 @@ var v = new C().m(1, b: 'bbb', c: 2.0);
         .test_unsafeBlockClosureInference_functionCall_explicitDynamicParam_viaExpr2();
   }
 
+  @override
+  @failingTest
+  void
+      test_unsafeBlockClosureInference_functionCall_explicitDynamicParam_viaExpr2_comment() {
+    super
+        .test_unsafeBlockClosureInference_functionCall_explicitDynamicParam_viaExpr2_comment();
+  }
+
   @override
   @failingTest
   void
@@ -623,12 +632,28 @@ var v = new C().m(1, b: 'bbb', c: 2.0);
         .test_unsafeBlockClosureInference_functionCall_explicitTypeParam_viaExpr2();
   }
 
+  @override
+  @failingTest
+  void
+      test_unsafeBlockClosureInference_functionCall_explicitTypeParam_viaExpr2_comment() {
+    super
+        .test_unsafeBlockClosureInference_functionCall_explicitTypeParam_viaExpr2_comment();
+  }
+
   @override
   @failingTest
   void test_unsafeBlockClosureInference_functionCall_implicitTypeParam() {
     super.test_unsafeBlockClosureInference_functionCall_implicitTypeParam();
   }
 
+  @override
+  @failingTest
+  void
+      test_unsafeBlockClosureInference_functionCall_implicitTypeParam_comment() {
+    super
+        .test_unsafeBlockClosureInference_functionCall_implicitTypeParam_comment();
+  }
+
   @override
   @failingTest
   void
@@ -637,6 +662,14 @@ var v = new C().m(1, b: 'bbb', c: 2.0);
         .test_unsafeBlockClosureInference_functionCall_implicitTypeParam_viaExpr();
   }
 
+  @override
+  @failingTest
+  void
+      test_unsafeBlockClosureInference_functionCall_implicitTypeParam_viaExpr_comment() {
+    super
+        .test_unsafeBlockClosureInference_functionCall_implicitTypeParam_viaExpr_comment();
+  }
+
   @override
   @failingTest
   void test_unsafeBlockClosureInference_functionCall_noTypeParam_viaExpr() {
@@ -661,6 +694,13 @@ var v = new C().m(1, b: 'bbb', c: 2.0);
     super.test_unsafeBlockClosureInference_methodCall_implicitTypeParam();
   }
 
+  @override
+  @failingTest
+  void test_unsafeBlockClosureInference_methodCall_implicitTypeParam_comment() {
+    super
+        .test_unsafeBlockClosureInference_methodCall_implicitTypeParam_comment();
+  }
+
   LibraryElementImpl _checkSource(
       SummaryResynthesizer resynthesizer, Source source) {
     LibraryElementImpl resynthesized =
@@ -881,6 +921,12 @@ abstract class _ResynthesizeAstTest extends ResynthesizeTest
     Source source = addTestSource(text);
     LibraryElementImpl resynthesized = _encodeDecodeLibraryElement(source);
     LibraryElementImpl original = context.computeLibraryElement(source);
+    if (!allowErrors) {
+      List<AnalysisError> errors = context.computeErrors(source);
+      if (errors.where((e) => e.message.startsWith('unused')).isNotEmpty) {
+        fail('Analysis errors: $errors');
+      }
+    }
     checkLibraryElements(original, resynthesized);
     return resynthesized;
   }
