@@ -4,9 +4,8 @@
 
 library analyzer.test.src.util.test_all;
 
-import 'package:unittest/unittest.dart';
+import 'package:test_reflective_loader/test_reflective_loader.dart';
 
-import '../../utils.dart';
 import 'absolute_path_test.dart' as absolute_path_test;
 import 'asserts_test.dart' as asserts_test;
 import 'fast_uri_test.dart' as fast_uri_test;
@@ -16,13 +15,12 @@ import 'yaml_test.dart' as yaml_test;
 
 /// Utility for manually running all tests.
 main() {
-  initializeTestEnvironment();
-  group('util tests', () {
+  defineReflectiveSuite(() {
     absolute_path_test.main();
     asserts_test.main();
     fast_uri_test.main();
     glob_test.main();
     lru_map_test.main();
     yaml_test.main();
-  });
+  }, name: 'util');
 }
